@@ -16,9 +16,4 @@ export var typeMapper = {
   radio: Radio,
   custom: Fragment,
   group: Group
-};
-export var groupType = {
-  checkbox: 'checkbox',
-  radio: 'radio',
-  plain: 'plain'
 };
\ No newline at end of file
