@@ -1,7 +1,8 @@
 export { default } from './ConditionalFilter';
 export { default as ConditionalFilter } from './ConditionalFilter';
-export { default as GroupFilter, groupType } from './GroupFilter';
+export { default as GroupFilter } from './GroupFilter';
 export { default as RadioFilter } from './RadioFilter';
 export { default as CheckboxFilter } from './CheckboxFilter';
 export { default as TextFilter } from './TextFilter';
+export { default as groupType } from './groupType';
 export * from './conditionalFilterConstants';
\ No newline at end of file
